==> QupZilla-2.0.0.tar.xz: QupZilla-2.0.0/src/plugins/StatusBarIcons/translations/hr_HR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr_HR" version="2.0">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Izmijeni postavke učitavanja slike  po stranici i globalno</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current page settings</source>
        <translation>Postavke trenutne stranice</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Onemogući učitavanje slika (privremeno)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Omogući učitavanje slika (privremeno)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global settings</source>
        <translation>Globalne postavke</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>Automatski učitaj slike</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Izmijeni JavaScript postavke po svakoj stranici i globalno</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="48"/>
        <source>Current page settings</source>
        <translation>Postavke trenutne stranice</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="51"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>Onemogući JavaScript (privremeno)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="54"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>Omogući JavaScript (privremeno)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="63"/>
        <source>Global settings</source>
        <translation>Globalne postavke</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="64"/>
        <source>Manage JavaScript settings</source>
        <translation>Upravljaj JavaScript postavkama</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Proxy configuration</source>
        <translation>Proxy podešavanje</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="68"/>
        <source>Select proxy</source>
        <translation>Odaberi proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="82"/>
        <source>Empty</source>
        <translation>Prazno</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="86"/>
        <source>Manage proxies</source>
        <translation>Upravljaj proxsijima</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="99"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Prikaži stanje mreže i upravljaj proxyjem&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Mreža:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="102"/>
        <source>Connected</source>
        <translation>Povezan</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="105"/>
        <source>Offline</source>
        <translation>Izvanmrežno</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="110"/>
        <source>System proxy</source>
        <translation>Proxy sustava</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="114"/>
        <source>No proxy</source>
        <translation>Bez proxya</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="118"/>
        <source>PAC (Proxy Auto-Config)</source>
        <translation>PAC (Proxy Auto-Config)</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="122"/>
        <source>User defined</source>
        <translation>Korisnički definirano</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Proxy upravitelj</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Odaberi proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Add proxy</source>
        <translation>Dodaj proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Ukloni proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>Nema proxija. Možete dodati proxy klikom na &lt;b&gt;Dodaj&lt;/b&gt; tipku.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Sve promjene moraju biti spremljene pomoću &lt;b&gt;Spremi&lt;/b&gt; tipkom.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Name of proxy:</source>
        <translation>Proxy naziv:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Remove current proxy</source>
        <translation>Ukloni trenutni proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Are you sure to remove current proxy?</source>
        <translation>Sigurno želite ukloniti trenutni proxy?</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>Oblik</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="20"/>
        <source>Do not use proxy</source>
        <translation>Ne koristi proxy</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="27"/>
        <source>Use different proxy for https connection</source>
        <translation>Koristi različiti proxy za HTTPS povezivanje</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="34"/>
        <source>&lt;b&gt;Exceptions&lt;/b&gt;</source>
        <translation>&lt;b&gt;Iznimke&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="43"/>
        <source>Don&apos;t use on:</source>
        <translation>Ne koristi na:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="58"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="63"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="74"/>
        <location filename="../sbi_proxywidget.ui" line="220"/>
        <source>Port:</source>
        <translation>Ulaz:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <location filename="../sbi_proxywidget.ui" line="243"/>
        <source>Username:</source>
        <translation>Korisničko ime:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="121"/>
        <location filename="../sbi_proxywidget.ui" line="253"/>
        <source>Password:</source>
        <translation>Lozinka:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="146"/>
        <source>Use script for automatic configuration:</source>
        <translation>Koristi skriptu za automatsko podešavanje:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="153"/>
        <source>System proxy configuration</source>
        <translation>Podešavanje proxyja sustava</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="162"/>
        <source>Proxy Auto-Config (.pac) file</source>
        <translation>Proxy Auto-Config (.pac) datoteka</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="187"/>
        <source>Manual configuration</source>
        <translation>Ručno podešavanje</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="210"/>
        <source>Server:</source>
        <translation>Poslužitelj:</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Ikone statusne trake</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Ikone statusne trake&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Ove će ikone biti prikazane u statusnoj traci:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Slike ikona</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>JavaScript ikona</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Mrežna ikona</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>Widget zumiranja</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>Zumiranje: %1%</translation>
    </message>
</context>
</TS>

==> QupZilla-2.0.2.tar.xz: QupZilla-2.0.2/src/plugins/StatusBarIcons/translations/hr_HR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr_HR" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Izmijeni postavke učitavanja slike  po stranici i globalno</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current Page Settings</source>
        <translation>Postavke trenutne stranice</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Onemogući učitavanje slika (privremeno)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Omogući učitavanje slika (privremeno)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>Opće postavke</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>Automatski učitaj slike</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Izmijeni JavaScript postavke po svakoj stranici i globalno</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="50"/>
        <source>Current Page Settings</source>
        <translation>Postavke trenutne stranice</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="53"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>Onemogući JavaScript (privremeno)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="56"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>Omogući JavaScript (privremeno)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="65"/>
        <source>Global Settings</source>
        <translation>Opće postavke</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Manage JavaScript settings</source>
        <translation>Upravljaj JavaScript postavkama</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="64"/>
        <source>Proxy Configuration</source>
        <translation>Proxy postavke</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Select proxy</source>
        <translation>Odaberi proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="80"/>
        <source>Empty</source>
        <translation>Prazno</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="84"/>
        <source>Manage proxies</source>
        <translation>Upravljaj proxsijima</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="97"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Prikaži stanje mreže i upravljaj proxyjem&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Mreža:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="100"/>
        <source>Connected</source>
        <translation>Povezan</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="103"/>
        <source>Offline</source>
        <translation>Izvanmrežno</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="108"/>
        <source>System proxy</source>
        <translation>Proxy sustava</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="112"/>
        <source>No proxy</source>
        <translation>Bez proxya</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="116"/>
        <source>User defined</source>
        <translation>Korisnički definirano</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Proxy upravitelj</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Odaberi proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>Dodaj proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Ukloni proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>Nema proxija. Možete dodati proxy klikom na &lt;b&gt;Dodaj&lt;/b&gt; tipku.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Sve promjene moraju biti spremljene pomoću &lt;b&gt;Spremi&lt;/b&gt; tipkom.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>Proxy naziv:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>Ukloni trenutni proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>Oblik</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>Ulaz:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>Korisničko ime:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>Lozinka:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Ikone statusne trake</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Ikone statusne trake&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Ove će ikone biti prikazane u statusnoj traci:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Slike ikona</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>JavaScript ikona</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Mrežna ikona</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>Widget zumiranja</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>Zumiranje: %1%</translation>
    </message>
</context>
</TS>
